Dojo Tooltip Widget Test

# Tooltip test

Mouse-over or focus the items below to test tooltips.

Change tooltip positioning search list: | Set background color: | Prompt message test (for quirks mode):
Current: default (unchanged) |  |

Drop down menu items have tooltips:
tooltip for cut tooltip for copy tooltip for paste
hover me for tooltip tooltip on TitlePane span
focusable text rich formatting !
plain text (not focusable) keyboard users can not access this tooltip anchor tooltip on a link

this text has a programmatically created tooltip
tooltip on a button
tooltip from "button w/tooltip". Test tooltip on right aligned element. Tooltip should flow to the left -->
tooltip on a select
two line tooltip.

s1 text
s2 text
s3 text
s4 text
s5 text
tooltip for #1
long long long long long long long long long long long text
make sure that this works properly with a really narrow window tooltip for #2 tooltip for #3 tooltip for #4 tooltip for #5 tooltip for #6 s1 tooltip s2 tooltip s3 tooltip s4 tooltip s5 tooltip

### One Tooltip for multiple connect nodes

multi tooltip multi1
multi2

### One Tooltip for multiple connect nodes w/ dojoType

multi tooltip dojoType multi1
multi2

### Dynamic target tooltip

t1 text
t2 text
t3 text
t4 text
t5 text
Tooltip hidden (initial) Dynamic target tooltip

### Nested div test:

Mouse over the inner blue div should show the tooltip on this outer yellow div.
inner blue div
Likewise, focusing the input should put the tooltip on the outer yellow div
Tooltip on yellow outer div

### Delegation test:

Tooltip should appear for first three rows of the table, customized per row.

This text will never appear; instead getContent() will run.

row | 1
row | 2
row | 3
row | 4
row | 5